v1

package
v0.4.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package v1 contains API Schema definitions for the secrets v1 API group +kubebuilder:object:generate=true +groupName=kms.hanzo.ai

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "kms.hanzo.ai", Version: "v1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type AWSIamAuthDetails

type AWSIamAuthDetails struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`

	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`
}

func (*AWSIamAuthDetails) DeepCopy

func (in *AWSIamAuthDetails) DeepCopy() *AWSIamAuthDetails

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AWSIamAuthDetails.

func (*AWSIamAuthDetails) DeepCopyInto

func (in *AWSIamAuthDetails) DeepCopyInto(out *AWSIamAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type Authentication

type Authentication struct {
	// +kubebuilder:validation:Optional
	ServiceAccount ServiceAccountDetails `json:"serviceAccount"`
	// +kubebuilder:validation:Optional
	ServiceToken ServiceTokenDetails `json:"serviceToken"`
	// +kubebuilder:validation:Optional
	UniversalAuth UniversalAuthDetails `json:"universalAuth"`
	// +kubebuilder:validation:Optional
	KubernetesAuth KubernetesAuthDetails `json:"kubernetesAuth"`
	// +kubebuilder:validation:Optional
	AwsIamAuth AWSIamAuthDetails `json:"awsIamAuth"`
	// +kubebuilder:validation:Optional
	AzureAuth AzureAuthDetails `json:"azureAuth"`
	// +kubebuilder:validation:Optional
	GcpIdTokenAuth GCPIdTokenAuthDetails `json:"gcpIdTokenAuth"`
	// +kubebuilder:validation:Optional
	GcpIamAuth GcpIamAuthDetails `json:"gcpIamAuth"`
}

func (*Authentication) DeepCopy

func (in *Authentication) DeepCopy() *Authentication

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Authentication.

func (*Authentication) DeepCopyInto

func (in *Authentication) DeepCopyInto(out *Authentication)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type AzureAuthDetails

type AzureAuthDetails struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Optional
	Resource string `json:"resource"`

	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`
}

func (*AzureAuthDetails) DeepCopy

func (in *AzureAuthDetails) DeepCopy() *AzureAuthDetails

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AzureAuthDetails.

func (*AzureAuthDetails) DeepCopyInto

func (in *AzureAuthDetails) DeepCopyInto(out *AzureAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CaReference

type CaReference struct {
	// The name of the Kubernetes Secret
	// +kubebuilder:validation:Required
	SecretName string `json:"secretName"`

	// The namespace where the Kubernetes Secret is located
	// +kubebuilder:validation:Required
	SecretNamespace string `json:"secretNamespace"`

	// +kubebuilder:validation:Required
	// The name of the secret property with the CA certificate value
	SecretKey string `json:"key"`
}

func (*CaReference) DeepCopy

func (in *CaReference) DeepCopy() *CaReference

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CaReference.

func (*CaReference) DeepCopyInto

func (in *CaReference) DeepCopyInto(out *CaReference)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterGenerator

type ClusterGenerator struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec ClusterGeneratorSpec `json:"spec,omitempty"`
}

ClusterGenerator represents a cluster-wide generator +kubebuilder:object:root=true +kubebuilder:storageversion +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster

func (*ClusterGenerator) DeepCopy

func (in *ClusterGenerator) DeepCopy() *ClusterGenerator

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGenerator.

func (*ClusterGenerator) DeepCopyInto

func (in *ClusterGenerator) DeepCopyInto(out *ClusterGenerator)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterGenerator) DeepCopyObject

func (in *ClusterGenerator) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterGeneratorList

type ClusterGeneratorList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ClusterGenerator `json:"items"`
}

ClusterGeneratorList contains a list of ClusterGenerator resources.

func (*ClusterGeneratorList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGeneratorList.

func (*ClusterGeneratorList) DeepCopyInto

func (in *ClusterGeneratorList) DeepCopyInto(out *ClusterGeneratorList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterGeneratorList) DeepCopyObject

func (in *ClusterGeneratorList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterGeneratorSpec

type ClusterGeneratorSpec struct {
	// Kind the kind of this generator.
	Kind GeneratorKind `json:"kind"`

	// Generator the spec for this generator, must match the kind.
	Generator GeneratorSpec `json:"generator,omitempty"`
}

func (*ClusterGeneratorSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterGeneratorSpec.

func (*ClusterGeneratorSpec) DeepCopyInto

func (in *ClusterGeneratorSpec) DeepCopyInto(out *ClusterGeneratorSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GCPIdTokenAuthDetails

type GCPIdTokenAuthDetails struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`

	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`
}

func (*GCPIdTokenAuthDetails) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GCPIdTokenAuthDetails.

func (*GCPIdTokenAuthDetails) DeepCopyInto

func (in *GCPIdTokenAuthDetails) DeepCopyInto(out *GCPIdTokenAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GcpIamAuthDetails

type GcpIamAuthDetails struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Required
	ServiceAccountKeyFilePath string `json:"serviceAccountKeyFilePath"`

	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`
}

func (*GcpIamAuthDetails) DeepCopy

func (in *GcpIamAuthDetails) DeepCopy() *GcpIamAuthDetails

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GcpIamAuthDetails.

func (*GcpIamAuthDetails) DeepCopyInto

func (in *GcpIamAuthDetails) DeepCopyInto(out *GcpIamAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GeneratorKind

type GeneratorKind string

GeneratorKind represents a kind of generator. +kubebuilder:validation:Enum=Password;UUID

const (
	GeneratorKindPassword GeneratorKind = "Password"
	GeneratorKindUUID     GeneratorKind = "UUID"
)

type GeneratorRef

type GeneratorRef struct {
	// Specify the Kind of the generator resource
	// +kubebuilder:validation:Enum=Password;UUID
	// +kubebuilder:validation:Required
	Kind GeneratorKind `json:"kind"`

	// +kubebuilder:validation:Required
	Name string `json:"name"`
}

func (*GeneratorRef) DeepCopy

func (in *GeneratorRef) DeepCopy() *GeneratorRef

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GeneratorRef.

func (*GeneratorRef) DeepCopyInto

func (in *GeneratorRef) DeepCopyInto(out *GeneratorRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GeneratorSpec

type GeneratorSpec struct {
	// +kubebuilder:validation:Optional
	PasswordSpec *PasswordSpec `json:"passwordSpec,omitempty"`
	// +kubebuilder:validation:Optional
	UUIDSpec *UUIDSpec `json:"uuidSpec,omitempty"`
}

func (*GeneratorSpec) DeepCopy

func (in *GeneratorSpec) DeepCopy() *GeneratorSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GeneratorSpec.

func (*GeneratorSpec) DeepCopyInto

func (in *GeneratorSpec) DeepCopyInto(out *GeneratorSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericAwsIamAuth

type GenericAwsIamAuth struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
}

func (*GenericAwsIamAuth) DeepCopy

func (in *GenericAwsIamAuth) DeepCopy() *GenericAwsIamAuth

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericAwsIamAuth.

func (*GenericAwsIamAuth) DeepCopyInto

func (in *GenericAwsIamAuth) DeepCopyInto(out *GenericAwsIamAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericAzureAuth

type GenericAzureAuth struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Optional
	Resource string `json:"resource,omitempty"`
}

func (*GenericAzureAuth) DeepCopy

func (in *GenericAzureAuth) DeepCopy() *GenericAzureAuth

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericAzureAuth.

func (*GenericAzureAuth) DeepCopyInto

func (in *GenericAzureAuth) DeepCopyInto(out *GenericAzureAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericGcpIamAuth

type GenericGcpIamAuth struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Required
	ServiceAccountKeyFilePath string `json:"serviceAccountKeyFilePath"`
}

func (*GenericGcpIamAuth) DeepCopy

func (in *GenericGcpIamAuth) DeepCopy() *GenericGcpIamAuth

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericGcpIamAuth.

func (*GenericGcpIamAuth) DeepCopyInto

func (in *GenericGcpIamAuth) DeepCopyInto(out *GenericGcpIamAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericGcpIdTokenAuth

type GenericGcpIdTokenAuth struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
}

func (*GenericGcpIdTokenAuth) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericGcpIdTokenAuth.

func (*GenericGcpIdTokenAuth) DeepCopyInto

func (in *GenericGcpIdTokenAuth) DeepCopyInto(out *GenericGcpIdTokenAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericKMSAuthentication

type GenericKMSAuthentication struct {
	// +kubebuilder:validation:Optional
	UniversalAuth GenericUniversalAuth `json:"universalAuth,omitempty"`
	// +kubebuilder:validation:Optional
	KubernetesAuth GenericKubernetesAuth `json:"kubernetesAuth,omitempty"`
	// +kubebuilder:validation:Optional
	AwsIamAuth GenericAwsIamAuth `json:"awsIamAuth,omitempty"`
	// +kubebuilder:validation:Optional
	AzureAuth GenericAzureAuth `json:"azureAuth,omitempty"`
	// +kubebuilder:validation:Optional
	GcpIdTokenAuth GenericGcpIdTokenAuth `json:"gcpIdTokenAuth,omitempty"`
	// +kubebuilder:validation:Optional
	GcpIamAuth GenericGcpIamAuth `json:"gcpIamAuth,omitempty"`
}

func (*GenericKMSAuthentication) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericKMSAuthentication.

func (*GenericKMSAuthentication) DeepCopyInto

func (in *GenericKMSAuthentication) DeepCopyInto(out *GenericKMSAuthentication)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericKubernetesAuth

type GenericKubernetesAuth struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Required
	ServiceAccountRef KubernetesServiceAccountRef `json:"serviceAccountRef"`

	// Optionally automatically create a service account token for the configured service account.
	// If this is set to `true`, the operator will automatically create a service account token for the configured service account. This field is recommended in most cases.
	// +kubebuilder:validation:Optional
	AutoCreateServiceAccountToken bool `json:"autoCreateServiceAccountToken"`
	// The audiences to use for the service account token. This is only relevant if `autoCreateServiceAccountToken` is true.
	// +kubebuilder:validation:Optional
	ServiceAccountTokenAudiences []string `json:"serviceAccountTokenAudiences"`
}

func (*GenericKubernetesAuth) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericKubernetesAuth.

func (*GenericKubernetesAuth) DeepCopyInto

func (in *GenericKubernetesAuth) DeepCopyInto(out *GenericKubernetesAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type GenericUniversalAuth

type GenericUniversalAuth struct {
	// +kubebuilder:validation:Required
	CredentialsRef KubeSecretReference `json:"credentialsRef"`
}

func (*GenericUniversalAuth) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GenericUniversalAuth.

func (*GenericUniversalAuth) DeepCopyInto

func (in *GenericUniversalAuth) DeepCopyInto(out *GenericUniversalAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSPushSecret

type KMSPushSecret struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   KMSPushSecretSpec   `json:"spec,omitempty"`
	Status KMSPushSecretStatus `json:"status,omitempty"`
}

+kubebuilder:object:root=true +kubebuilder:subresource:status KMSPushSecret is the Schema for the kmspushsecrets API

func (*KMSPushSecret) DeepCopy

func (in *KMSPushSecret) DeepCopy() *KMSPushSecret

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecret.

func (*KMSPushSecret) DeepCopyInto

func (in *KMSPushSecret) DeepCopyInto(out *KMSPushSecret)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*KMSPushSecret) DeepCopyObject

func (in *KMSPushSecret) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type KMSPushSecretDestination

type KMSPushSecretDestination struct {
	// +kubebuilder:validation:Required
	// +kubebuilder:validation:Immutable
	SecretsPath string `json:"secretsPath"`
	// +kubebuilder:validation:Required
	// +kubebuilder:validation:Immutable
	EnvironmentSlug string `json:"environmentSlug"`
	// +kubebuilder:validation:Required
	// +kubebuilder:validation:Immutable
	ProjectID string `json:"projectId"`
}

func (*KMSPushSecretDestination) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecretDestination.

func (*KMSPushSecretDestination) DeepCopyInto

func (in *KMSPushSecretDestination) DeepCopyInto(out *KMSPushSecretDestination)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSPushSecretList

type KMSPushSecretList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []KMSPushSecret `json:"items"`
}

KMSPushSecretList contains a list of KMSPushSecret

func (*KMSPushSecretList) DeepCopy

func (in *KMSPushSecretList) DeepCopy() *KMSPushSecretList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecretList.

func (*KMSPushSecretList) DeepCopyInto

func (in *KMSPushSecretList) DeepCopyInto(out *KMSPushSecretList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*KMSPushSecretList) DeepCopyObject

func (in *KMSPushSecretList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type KMSPushSecretSecretSource

type KMSPushSecretSecretSource struct {
	// The name of the Kubernetes Secret
	// +kubebuilder:validation:Required
	SecretName string `json:"secretName"`

	// The name space where the Kubernetes Secret is located
	// +kubebuilder:validation:Required
	SecretNamespace string `json:"secretNamespace"`

	// +kubebuilder:validation:Optional
	Template *SecretTemplate `json:"template,omitempty"`
}

func (*KMSPushSecretSecretSource) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecretSecretSource.

func (*KMSPushSecretSecretSource) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSPushSecretSpec

type KMSPushSecretSpec struct {
	// +kubebuilder:validation:Optional
	UpdatePolicy string `json:"updatePolicy"`

	// +kubebuilder:validation:Optional
	DeletionPolicy string `json:"deletionPolicy"`

	// +kubebuilder:validation:Required
	// +kubebuilder:validation:Immutable
	Destination KMSPushSecretDestination `json:"destination"`

	// +kubebuilder:validation:Optional
	Authentication GenericKMSAuthentication `json:"authentication"`

	// +kubebuilder:validation:Required
	Push SecretPush `json:"push"`

	// +kubebuilder:validation:Optional
	ResyncInterval *string `json:"resyncInterval,omitempty"`

	// KMS host to pull secrets from
	// +kubebuilder:validation:Optional
	HostAPI string `json:"hostAPI"`

	// +kubebuilder:validation:Optional
	TLS TLSConfig `json:"tls"`

	// ServicePath is the canonical service identity path used to derive
	// the consumer's NodeID. See KMSSecretSpec.ServicePath.
	// +kubebuilder:validation:Optional
	ServicePath string `json:"servicePath,omitempty"`

	// MnemonicSecretRef points at a Secret holding the BIP-39 mnemonic
	// that derives this consumer's identity. See KMSSecretSpec.MnemonicSecretRef.
	// +kubebuilder:validation:Optional
	MnemonicSecretRef KubeSecretReference `json:"mnemonicSecretRef,omitempty"`
}

KMSPushSecretSpec defines the desired state of KMSPushSecret

func (*KMSPushSecretSpec) DeepCopy

func (in *KMSPushSecretSpec) DeepCopy() *KMSPushSecretSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecretSpec.

func (*KMSPushSecretSpec) DeepCopyInto

func (in *KMSPushSecretSpec) DeepCopyInto(out *KMSPushSecretSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSPushSecretStatus

type KMSPushSecretStatus struct {
	Conditions []metav1.Condition `json:"conditions"`

	// managed secrets is a map where the key is the ID, and the value is the secret key (string[id], string[key] )
	ManagedSecrets map[string]string `json:"managedSecrets"`
}

KMSPushSecretStatus defines the observed state of KMSPushSecret

func (*KMSPushSecretStatus) DeepCopy

func (in *KMSPushSecretStatus) DeepCopy() *KMSPushSecretStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSPushSecretStatus.

func (*KMSPushSecretStatus) DeepCopyInto

func (in *KMSPushSecretStatus) DeepCopyInto(out *KMSPushSecretStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSSecret

type KMSSecret struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   KMSSecretSpec   `json:"spec,omitempty"`
	Status KMSSecretStatus `json:"status,omitempty"`
}

KMSSecret is the Schema for the kmssecrets API

func (*KMSSecret) DeepCopy

func (in *KMSSecret) DeepCopy() *KMSSecret

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSSecret.

func (*KMSSecret) DeepCopyInto

func (in *KMSSecret) DeepCopyInto(out *KMSSecret)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*KMSSecret) DeepCopyObject

func (in *KMSSecret) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type KMSSecretList

type KMSSecretList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []KMSSecret `json:"items"`
}

KMSSecretList contains a list of KMSSecret

func (*KMSSecretList) DeepCopy

func (in *KMSSecretList) DeepCopy() *KMSSecretList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSSecretList.

func (*KMSSecretList) DeepCopyInto

func (in *KMSSecretList) DeepCopyInto(out *KMSSecretList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*KMSSecretList) DeepCopyObject

func (in *KMSSecretList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type KMSSecretSpec

type KMSSecretSpec struct {
	// +kubebuilder:validation:Optional
	TokenSecretReference KubeSecretReference `json:"tokenSecretReference"`

	// +kubebuilder:validation:Optional
	Authentication Authentication `json:"authentication"`

	// +kubebuilder:validation:Optional
	ManagedSecretReference ManagedKubeSecretConfig `json:"managedSecretReference"`

	// +kubebuilder:validation:Optional
	ManagedKubeSecretReferences []ManagedKubeSecretConfig `json:"managedKubeSecretReferences"`
	// +kubebuilder:validation:Optional
	ManagedKubeConfigMapReferences []ManagedKubeConfigMapConfig `json:"managedKubeConfigMapReferences"`

	// +kubebuilder:default:=60
	ResyncInterval int `json:"resyncInterval"`

	// KMS host to pull secrets from
	// +kubebuilder:validation:Optional
	HostAPI string `json:"hostAPI"`

	// +kubebuilder:validation:Optional
	TLS TLSConfig `json:"tls"`

	// ServicePath is the canonical service identity path used to derive
	// the consumer's NodeID (see luxfi/keys.NewServiceIdentity). Empty
	// → "hanzo/<crname>". Identical paths derive identical NodeIDs from
	// the same mnemonic, so do not reuse a path across distinct
	// services.
	// +kubebuilder:validation:Optional
	ServicePath string `json:"servicePath,omitempty"`

	// MnemonicSecretRef points at a Secret holding the BIP-39 mnemonic
	// that derives this consumer's identity. Empty → defaults to
	// "<crname>-mnemonic" in the same namespace as the CR. The Secret
	// is generated and persisted by the operator on first reconcile
	// when it does not exist. The mnemonic itself is NEVER written to
	// CR status, logs, events, or any non-Secret resource.
	// +kubebuilder:validation:Optional
	MnemonicSecretRef KubeSecretReference `json:"mnemonicSecretRef,omitempty"`
}

KMSSecretSpec defines the desired state of KMSSecret

func (*KMSSecretSpec) DeepCopy

func (in *KMSSecretSpec) DeepCopy() *KMSSecretSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSSecretSpec.

func (*KMSSecretSpec) DeepCopyInto

func (in *KMSSecretSpec) DeepCopyInto(out *KMSSecretSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSSecretStatus

type KMSSecretStatus struct {
	Conditions []metav1.Condition `json:"conditions"`
}

KMSSecretStatus defines the observed state of KMSSecret

func (*KMSSecretStatus) DeepCopy

func (in *KMSSecretStatus) DeepCopy() *KMSSecretStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSSecretStatus.

func (*KMSSecretStatus) DeepCopyInto

func (in *KMSSecretStatus) DeepCopyInto(out *KMSSecretStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubeSecretReference

type KubeSecretReference struct {
	// The name of the Kubernetes Secret
	// +kubebuilder:validation:Required
	SecretName string `json:"secretName"`

	// The name space where the Kubernetes Secret is located
	// +kubebuilder:validation:Required
	SecretNamespace string `json:"secretNamespace"`
}

func (*KubeSecretReference) DeepCopy

func (in *KubeSecretReference) DeepCopy() *KubeSecretReference

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubeSecretReference.

func (*KubeSecretReference) DeepCopyInto

func (in *KubeSecretReference) DeepCopyInto(out *KubeSecretReference)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubernetesAuthDetails

type KubernetesAuthDetails struct {
	// +kubebuilder:validation:Required
	IdentityID string `json:"identityId"`
	// +kubebuilder:validation:Required
	ServiceAccountRef KubernetesServiceAccountRef `json:"serviceAccountRef"`

	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`

	// Optionally automatically create a service account token for the configured service account.
	// If this is set to `true`, the operator will automatically create a service account token for the configured service account.
	// +kubebuilder:validation:Optional
	AutoCreateServiceAccountToken bool `json:"autoCreateServiceAccountToken"`
	// The audiences to use for the service account token. This is only relevant if `autoCreateServiceAccountToken` is true.
	// +kubebuilder:validation:Optional
	ServiceAccountTokenAudiences []string `json:"serviceAccountTokenAudiences"`
}

func (*KubernetesAuthDetails) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubernetesAuthDetails.

func (*KubernetesAuthDetails) DeepCopyInto

func (in *KubernetesAuthDetails) DeepCopyInto(out *KubernetesAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubernetesServiceAccountRef

type KubernetesServiceAccountRef struct {
	// +kubebuilder:validation:Required
	Name string `json:"name"`
	// +kubebuilder:validation:Required
	Namespace string `json:"namespace"`
}

func (*KubernetesServiceAccountRef) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubernetesServiceAccountRef.

func (*KubernetesServiceAccountRef) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type MachineIdentityScopeInWorkspace

type MachineIdentityScopeInWorkspace struct {
	// SecretsPath is the path under which the listed Keys live. Empty
	// path means the org root. Leading and trailing "/" are stripped.
	// +kubebuilder:validation:Required
	SecretsPath string `json:"secretsPath"`
	// EnvSlug is the environment scope (for example "dev", "mainnet").
	// +kubebuilder:validation:Required
	EnvSlug string `json:"envSlug"`
	// ProjectSlug names the org under the canonical luxfi/kms surface
	// — secrets are addressed as /v1/kms/orgs/{projectSlug}/secrets/...
	// +kubebuilder:validation:Required
	ProjectSlug string `json:"projectSlug"`
	// Keys enumerates the secret names to fetch from the KMS. The
	// canonical surface has no list endpoint; every value MUST be
	// addressed by exact name. Bounded ≤ 128 entries / CR.
	// +kubebuilder:validation:Required
	// +kubebuilder:validation:MinItems=1
	// +kubebuilder:validation:MaxItems=128
	Keys []string `json:"keys"`
}

func (*MachineIdentityScopeInWorkspace) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineIdentityScopeInWorkspace.

func (*MachineIdentityScopeInWorkspace) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ManagedKubeConfigMapConfig

type ManagedKubeConfigMapConfig struct {
	// The name of the Kubernetes ConfigMap
	// +kubebuilder:validation:Required
	ConfigMapName string `json:"configMapName"`

	// The Kubernetes ConfigMap creation policy.
	// Enum with values: 'Owner', 'Orphan'.
	// Owner creates the config map and sets .metadata.ownerReferences of the KMSSecret CRD that created it.
	// Orphan will not set the config map owner. This will result in the config map being orphaned and not deleted when the resource is deleted.
	// +kubebuilder:validation:Optional
	// +kubebuilder:default:=Orphan
	CreationPolicy string `json:"creationPolicy"`

	// The namespace where the Kubernetes ConfigMap is located
	// +kubebuilder:validation:Required
	ConfigMapNamespace string `json:"configMapNamespace"`

	// The template to transform the secret data
	// +kubebuilder:validation:Optional
	Template *SecretTemplate `json:"template,omitempty"`
}

func (*ManagedKubeConfigMapConfig) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ManagedKubeConfigMapConfig.

func (*ManagedKubeConfigMapConfig) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ManagedKubeSecretConfig

type ManagedKubeSecretConfig struct {
	// The name of the Kubernetes Secret
	// +kubebuilder:validation:Required
	SecretName string `json:"secretName"`

	// The name space where the Kubernetes Secret is located
	// +kubebuilder:validation:Required
	SecretNamespace string `json:"secretNamespace"`

	// The Kubernetes Secret type (experimental feature). More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types
	// +kubebuilder:validation:Optional
	// +kubebuilder:default:=Opaque
	SecretType string `json:"secretType"`

	// The Kubernetes Secret creation policy.
	// Enum with values: 'Owner', 'Orphan'.
	// Owner creates the secret and sets .metadata.ownerReferences of the KMSSecret CRD that created it.
	// Orphan will not set the secret owner. This will result in the secret being orphaned and not deleted when the resource is deleted.
	// +kubebuilder:validation:Optional
	// +kubebuilder:default:=Orphan
	CreationPolicy string `json:"creationPolicy"`

	// The template to transform the secret data
	// +kubebuilder:validation:Optional
	Template *SecretTemplate `json:"template,omitempty"`
}

func (*ManagedKubeSecretConfig) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ManagedKubeSecretConfig.

func (*ManagedKubeSecretConfig) DeepCopyInto

func (in *ManagedKubeSecretConfig) DeepCopyInto(out *ManagedKubeSecretConfig)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type Password

type Password struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec PasswordSpec `json:"spec,omitempty"`
}

Password generates a random password based on the configuration parameters in spec. You can specify the length, characterset and other attributes. +kubebuilder:object:root=true +kubebuilder:storageversion +kubebuilder:subresource:status +kubebuilder:resource:scope=Namespaced

func (*Password) DeepCopy

func (in *Password) DeepCopy() *Password

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Password.

func (*Password) DeepCopyInto

func (in *Password) DeepCopyInto(out *Password)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Password) DeepCopyObject

func (in *Password) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type PasswordList

type PasswordList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []Password `json:"items"`
}

PasswordList contains a list of Password resources.

func (*PasswordList) DeepCopy

func (in *PasswordList) DeepCopy() *PasswordList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PasswordList.

func (*PasswordList) DeepCopyInto

func (in *PasswordList) DeepCopyInto(out *PasswordList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*PasswordList) DeepCopyObject

func (in *PasswordList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type PasswordSpec

type PasswordSpec struct {
	// Length of the password to be generated.
	// Defaults to 24
	// +kubebuilder:validation:Optional
	// +kubebuilder:default=24
	Length int `json:"length"`

	// digits specifies the number of digits in the generated
	// password. If omitted it defaults to 25% of the length of the password
	Digits *int `json:"digits,omitempty"`

	// symbols specifies the number of symbol characters in the generated
	// password. If omitted it defaults to 25% of the length of the password
	Symbols *int `json:"symbols,omitempty"`

	// symbolCharacters specifies the special characters that should be used
	// in the generated password.
	SymbolCharacters *string `json:"symbolCharacters,omitempty"`

	// Set noUpper to disable uppercase characters
	// +kubebuilder:validation:Optional
	// +kubebuilder:default=false
	NoUpper bool `json:"noUpper"`

	// set allowRepeat to true to allow repeating characters.
	// +kubebuilder:validation:Optional
	// +kubebuilder:default=false
	AllowRepeat bool `json:"allowRepeat"`
}

PasswordSpec controls the behavior of the password generator.

func (*PasswordSpec) DeepCopy

func (in *PasswordSpec) DeepCopy() *PasswordSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PasswordSpec.

func (*PasswordSpec) DeepCopyInto

func (in *PasswordSpec) DeepCopyInto(out *PasswordSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretPush

type SecretPush struct {
	// +kubebuilder:validation:Optional
	Secret *KMSPushSecretSecretSource `json:"secret,omitempty"`
	// +kubebuilder:validation:Optional
	Generators []SecretPushGenerator `json:"generators,omitempty"`
}

func (*SecretPush) DeepCopy

func (in *SecretPush) DeepCopy() *SecretPush

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretPush.

func (*SecretPush) DeepCopyInto

func (in *SecretPush) DeepCopyInto(out *SecretPush)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretPushGenerator

type SecretPushGenerator struct {
	// +kubebuilder:validation:Required
	DestinationSecretName string `json:"destinationSecretName"`
	// +kubebuilder:validation:Required
	GeneratorRef GeneratorRef `json:"generatorRef"`
}

func (*SecretPushGenerator) DeepCopy

func (in *SecretPushGenerator) DeepCopy() *SecretPushGenerator

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretPushGenerator.

func (*SecretPushGenerator) DeepCopyInto

func (in *SecretPushGenerator) DeepCopyInto(out *SecretPushGenerator)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretScopeInWorkspace

type SecretScopeInWorkspace struct {
	// +kubebuilder:validation:Required
	SecretsPath string `json:"secretsPath"`
	// +kubebuilder:validation:Required
	EnvSlug string `json:"envSlug"`
	// +kubebuilder:validation:Optional
	Recursive bool `json:"recursive"`
}

func (*SecretScopeInWorkspace) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretScopeInWorkspace.

func (*SecretScopeInWorkspace) DeepCopyInto

func (in *SecretScopeInWorkspace) DeepCopyInto(out *SecretScopeInWorkspace)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretTemplate

type SecretTemplate struct {
	// This injects all retrieved secrets into the top level of your template.
	// Secrets defined in the template will take precedence over the injected ones.
	// +kubebuilder:validation:Optional
	IncludeAllSecrets bool `json:"includeAllSecrets"`
	// The template key values
	// +kubebuilder:validation:Optional
	Data map[string]string `json:"data,omitempty"`
}

func (*SecretTemplate) DeepCopy

func (in *SecretTemplate) DeepCopy() *SecretTemplate

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretTemplate.

func (*SecretTemplate) DeepCopyInto

func (in *SecretTemplate) DeepCopyInto(out *SecretTemplate)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServiceAccountDetails

type ServiceAccountDetails struct {
	ServiceAccountSecretReference KubeSecretReference `json:"serviceAccountSecretReference"`
	ProjectId                     string              `json:"projectId"`
	EnvironmentName               string              `json:"environmentName"`
}

func (*ServiceAccountDetails) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceAccountDetails.

func (*ServiceAccountDetails) DeepCopyInto

func (in *ServiceAccountDetails) DeepCopyInto(out *ServiceAccountDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServiceTokenDetails

type ServiceTokenDetails struct {
	// +kubebuilder:validation:Required
	ServiceTokenSecretReference KubeSecretReference `json:"serviceTokenSecretReference"`
	// +kubebuilder:validation:Required
	SecretsScope SecretScopeInWorkspace `json:"secretsScope"`
}

func (*ServiceTokenDetails) DeepCopy

func (in *ServiceTokenDetails) DeepCopy() *ServiceTokenDetails

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceTokenDetails.

func (*ServiceTokenDetails) DeepCopyInto

func (in *ServiceTokenDetails) DeepCopyInto(out *ServiceTokenDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TLSConfig

type TLSConfig struct {
	// Reference to secret containing CA cert
	// +kubebuilder:validation:Optional
	CaRef CaReference `json:"caRef,omitempty"`
}

func (*TLSConfig) DeepCopy

func (in *TLSConfig) DeepCopy() *TLSConfig

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TLSConfig.

func (*TLSConfig) DeepCopyInto

func (in *TLSConfig) DeepCopyInto(out *TLSConfig)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type UUID

type UUID struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec UUIDSpec `json:"spec,omitempty"`
}

UUID generates a version 4 UUID (e56657e3-764f-11ef-a397-65231a88c216). +kubebuilder:object:root=true +kubebuilder:subresource:status

func (*UUID) DeepCopy

func (in *UUID) DeepCopy() *UUID

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UUID.

func (*UUID) DeepCopyInto

func (in *UUID) DeepCopyInto(out *UUID)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*UUID) DeepCopyObject

func (in *UUID) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type UUIDList

type UUIDList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []UUID `json:"items"`
}

UUIDList contains a list of UUID resources.

func (*UUIDList) DeepCopy

func (in *UUIDList) DeepCopy() *UUIDList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UUIDList.

func (*UUIDList) DeepCopyInto

func (in *UUIDList) DeepCopyInto(out *UUIDList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*UUIDList) DeepCopyObject

func (in *UUIDList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type UUIDSpec

type UUIDSpec struct{}

UUIDSpec controls the behavior of the uuid generator.

func (*UUIDSpec) DeepCopy

func (in *UUIDSpec) DeepCopy() *UUIDSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UUIDSpec.

func (*UUIDSpec) DeepCopyInto

func (in *UUIDSpec) DeepCopyInto(out *UUIDSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type UniversalAuthDetails

type UniversalAuthDetails struct {
	// +kubebuilder:validation:Required
	CredentialsRef KubeSecretReference `json:"credentialsRef"`
	// +kubebuilder:validation:Required
	SecretsScope MachineIdentityScopeInWorkspace `json:"secretsScope"`
}

func (*UniversalAuthDetails) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UniversalAuthDetails.

func (*UniversalAuthDetails) DeepCopyInto

func (in *UniversalAuthDetails) DeepCopyInto(out *UniversalAuthDetails)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to